pywr.recorders.RollingWindowParameterRecorder
=============================================

.. currentmodule:: pywr.recorders

.. autoclass:: RollingWindowParameterRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RollingWindowParameterRecorder.after
      ~RollingWindowParameterRecorder.aggregated_value
      ~RollingWindowParameterRecorder.before
      ~RollingWindowParameterRecorder.finish
      ~RollingWindowParameterRecorder.load
      ~RollingWindowParameterRecorder.register
      ~RollingWindowParameterRecorder.reset
      ~RollingWindowParameterRecorder.setup
      ~RollingWindowParameterRecorder.to_dataframe
      ~RollingWindowParameterRecorder.unregister
      ~RollingWindowParameterRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RollingWindowParameterRecorder.agg_func
      ~RollingWindowParameterRecorder.children
      ~RollingWindowParameterRecorder.comment
      ~RollingWindowParameterRecorder.data
      ~RollingWindowParameterRecorder.epsilon
      ~RollingWindowParameterRecorder.ignore_nan
      ~RollingWindowParameterRecorder.is_constraint
      ~RollingWindowParameterRecorder.is_objective
      ~RollingWindowParameterRecorder.model
      ~RollingWindowParameterRecorder.name
      ~RollingWindowParameterRecorder.parameter
      ~RollingWindowParameterRecorder.parents
      ~RollingWindowParameterRecorder.temporal_agg_func
      ~RollingWindowParameterRecorder.window
   
   